==> aliyun-java-sdk-mts-2.7.6-sources.jar: com/aliyuncs/mts/model/v20140618/CreateFpShotDBResponse.java <==
/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.aliyuncs.mts.model.v20140618;

import com.aliyuncs.AcsResponse;
import com.aliyuncs.mts.transform.v20140618.CreateFpShotDBResponseUnmarshaller;
import com.aliyuncs.transform.UnmarshallerContext;

/**
 * @author auto create
 * @version 
 */
public class CreateFpShotDBResponse extends AcsResponse {

	private String requestId;

	private FpShotDB fpShotDB;

	public String getRequestId() {
		return this.requestId;
	}

	public void setRequestId(String requestId) {
		this.requestId = requestId;
	}

	public FpShotDB getFpShotDB() {
		return this.fpShotDB;
	}

	public void setFpShotDB(FpShotDB fpShotDB) {
		this.fpShotDB = fpShotDB;
	}

	public static class FpShotDB {

		private String fpDBId;

		private String name;

		private Integer modelId;

		private String state;

		private String config;

		private String description;

		public String getFpDBId() {
			return this.fpDBId;
		}

		public void setFpDBId(String fpDBId) {
			this.fpDBId = fpDBId;
		}

		public String getName() {
			return this.name;
		}

		public void setName(String name) {
			this.name = name;
		}

		public Integer getModelId() {
			return this.modelId;
		}

		public void setModelId(Integer modelId) {
			this.modelId = modelId;
		}

		public String getState() {
			return this.state;
		}

		public void setState(String state) {
			this.state = state;
		}

		public String getConfig() {
			return this.config;
		}

		public void setConfig(String config) {
			this.config = config;
		}

		public String getDescription() {
			return this.description;
		}

		public void setDescription(String description) {
			this.description = description;
		}
	}

	@Override
	public CreateFpShotDBResponse getInstance(UnmarshallerContext context) {
		return	CreateFpShotDBResponseUnmarshaller.unmarshall(this, context);
	}
}

==> aliyun-java-sdk-mts-3.3.45-sources.jar: com/aliyuncs/mts/model/v20140618/CreateFpShotDBResponse.java <==
/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.aliyuncs.mts.model.v20140618;

import com.aliyuncs.AcsResponse;
import com.aliyuncs.mts.transform.v20140618.CreateFpShotDBResponseUnmarshaller;
import com.aliyuncs.transform.UnmarshallerContext;

/**
 * @author auto create
 * @version 
 */
public class CreateFpShotDBResponse extends AcsResponse {

	private String requestId;

	private FpShotDB fpShotDB;

	public String getRequestId() {
		return this.requestId;
	}

	public void setRequestId(String requestId) {
		this.requestId = requestId;
	}

	public FpShotDB getFpShotDB() {
		return this.fpShotDB;
	}

	public void setFpShotDB(FpShotDB fpShotDB) {
		this.fpShotDB = fpShotDB;
	}

	public static class FpShotDB {

		private String description;

		private String state;

		private String name;

		private String fpDBId;

		private Integer modelId;

		private String config;

		private String instanceId;

		public String getDescription() {
			return this.description;
		}

		public void setDescription(String description) {
			this.description = description;
		}

		public String getState() {
			return this.state;
		}

		public void setState(String state) {
			this.state = state;
		}

		public String getName() {
			return this.name;
		}

		public void setName(String name) {
			this.name = name;
		}

		public String getFpDBId() {
			return this.fpDBId;
		}

		public void setFpDBId(String fpDBId) {
			this.fpDBId = fpDBId;
		}

		public Integer getModelId() {
			return this.modelId;
		}

		public void setModelId(Integer modelId) {
			this.modelId = modelId;
		}

		public String getConfig() {
			return this.config;
		}

		public void setConfig(String config) {
			this.config = config;
		}

		public String getInstanceId() {
			return this.instanceId;
		}

		public void setInstanceId(String instanceId) {
			this.instanceId = instanceId;
		}
	}

	@Override
	public CreateFpShotDBResponse getInstance(UnmarshallerContext context) {
		return	CreateFpShotDBResponseUnmarshaller.unmarshall(this, context);
	}
}
